summaryrefslogtreecommitdiff
path: root/src/helper/command.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/helper/command.h')
-rw-r--r--src/helper/command.h6
1 files changed, 4 insertions, 2 deletions
diff --git a/src/helper/command.h b/src/helper/command.h
index 611db873..8d68c183 100644
--- a/src/helper/command.h
+++ b/src/helper/command.h
@@ -323,9 +323,11 @@ void command_set_output_handler(struct command_context* context,
int command_context_mode(struct command_context *context, enum command_mode mode);
/**
* Creates a new command context using the startup TCL provided.
*/
-struct command_context* command_init(const char *startup_tcl);
+struct command_context* command_init(const char *startup_tcl, Jim_Interp *interp);
/**
* Creates a copy of an existing command context. This does not create
* a deep copy of the command list, so modifications in one context will
@@ -323,9 +323,11 @@ void command_set_output_handler(struct command_context* context,
int command_context_mode(struct command_context *context, enum command_mode mode);
/**
- * Creates a new command context using the startup TCL provided.
+ * Creates a new command context using the startup TCL provided and
+ * the existing Jim interpreter, if any. If interp == NULL, then command_init
+ * creates a command interpreter.
*/